psychopy_ext.fmri.Preproc.split_rp — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.fmri.Preproc.split_rp

`Preproc.` `split_rp`(subjid)

  Splits the file that has realignment information by run.

  This is used for stats as each run with its covariates has to be entered separately.

  Assumptions:
    - Realignment parameters are supposed to be called like rp_afunc_<runno>.txt
    - Functional data is expected to be in the paths[‘data_fmri’] folder
    - paths[‘fmri_root’] should also be specified so that the original rp file would be backuped there.

  Args: | subjid (str) For which subject the split is done.